c          *****  program  wf_rhf (06.07.2007)  *****
c
c
c                1.0  PURPOSE OF THIS PROGRAM
c         1.1 to read  wave function from wf_rhf.src source file
c         1.2 to write wave function to output file (ASCII and HTM format)
c         1.3 to calculate total energy               
c         1.4 to test the ortogonalization conditions
c
c
c
c                 2.0  INPUT AND OUTPUT FILES
c         INPUTS FILES:
c                         wf_rhf.inp   - user input file
c                         wf_rhf.src   - source file of wave functions
c         OUTPUTS FILES:
c                         wf_rhf.out   - output file (ASCII)
c                         wf_rhf.htm   - output file in HTM format
c
c
c
c                 3.0  FORMAT OF USER INPUT FILE  (wf_rhf.inp)
c
c                    ne  z  key
c
c             ne   - number of electrons of atom or ion  (ne=2-54)
c             Z    - nuclear charge of ion               (Z=2.0 - 54.0)
c             key  - key of reference                    (key=1,2,3)
c
c
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      open(15,file='wf_rhf.out',status='unknown')
      open(11,file='wf_rhf.inp',status='old')
      read(11,*) ne,zt,key
      nzt=idint(zt*1.00001)
      call rd_rhf(ne,zt,key,kfind)
      call clrnn
      call wfout
      call wfhtm
      stop
      end

      subroutine rd_rhf(nei,zz,key1,kfind)
c---------- read  'wf_rhf.src' and find  wave function --------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      character h1*1,h80*80,title*80
      parameter   ( jcmain=50, jtabs=20)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs

      nsum=0
      kfind=0
      open(19,file='wf_rhf.tmp',status='unknown')
      open(12,file='wf_rhf.src',status='old')
      read(12,20) title
  20  format(a80)

   1  read(12,21,err=9,end=9) h1,h80
  21  format(a1,a80)
      if(h1.eq.'c' .or. h1.eq.'C') goto 1

   2  read(12,*,err=9,end=9) nex,nspx,lrx,zx,keyx
      if(nex.ne.nei.or.keyx.ne.key1.or.dabs(1.0-zx/zz).gt.0.01) then
   3       read(12,20) h80
           if(h80.ne.' ') goto 3
           goto 2
           else
   5  kfind=1
      nsptot=nspx
      lrtot=lrx
      ntab=0
   6  read(12,21) h1,h80
      if(h1.eq. ' '  .and.  h80.eq.' ') goto 8

      if(h1.eq.'#') then
      ntab=ntab+1
      write(19,20) h80
      backspace 19
      read(19,*)   nexnl(ntab),nlxnl(ntab),enl(ntab)
      nsum=nsum + nexnl(ntab)
      nn=0
      goto 6
      else
      nn=nn+1
      mxnlx(ntab)=nn
      write(19,21) h1,h80
      backspace 19
      read(19,*)   nlt(ntab,nn),gt(ntab,nn),at(ntab,nn)
      goto 6
      endif

   8  mxtabs=ntab

      endif
   9  close(12)

      if(nsum.ne.nei) write(* ,28) nei,nsum
      if(nsum.ne.nei) write(15,28) nei,nsum
      if(kfind.le.0) write(* ,29) nei,key1,zz
      if(kfind.le.0) write(15,29) nei,key1,zz
  28  format(' error wf-table:   nei=',i2,'  .ne.   nsum=',i2)
  29  format(' error: no data   nei=',i2,'  key=',i3,'  zz=',f6.1)
      return
      end

      subroutine clrnn
c----------------- calculate all values -----------------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      common/engrhf/ rx8(jtabs),rx9(jtabs),rx0(jtabs),rx1(jtabs),
     &     rx2(jtabs),tsm(jtabs),vsm(jtabs),vmn(jtabs,jtabs),
     &     fv12(jlmd,jtabs,jtabs),gv12(jlmd,jtabs,jtabs),
     &     eorbit(jtabs),etot,ekin,epot,ratio,v12
      dimension   gy(jcmain),ay(jcmain),nly(jcmain)
      dimension   nrnl(jtabs),lrnl(jtabs)

      zt=nzt
      do  101  m=1,mxtabs
      nex=nexnl(m)
      kmax=mxnlx(m)
      nrnl(m)= nlxnl(m) / 10
      lrnl(m)= nlxnl(m)  - 10*( nlxnl(m) / 10 )

            do 102 k=1,kmax
            nly(k)=nlt(m,k)
            gy(k)=gt(m,k)
            ay(k)=at(m,k)
  102       continue

      sum8=0.0
      sum9=0.0
      sum0=0.0
      sum1=0.0
      sum2=0.0
      tsum=0.0
      vsum=0.0

      do 2 j1=1,kmax
      nf1=nly(j1)/10
      lf1=nly(j1) - 10*nf1
      zf1=ay(j1)
      yf1= dsqrt( (2.*zf1)**(2*nf1+1) / fn(2*nf1) )

          do 1 i1=1,kmax
          ni1=nly(i1)/10
          li1=nly(i1) - 10*ni1
          zi1=ay(i1)
          yi1= dsqrt( (2.*zi1)**(2*ni1+1) / fn(2*ni1) )
      ss8= gy(i1)*gy(j1)*yf1*yi1*fn(nf1+ni1-2)/(zf1+zi1)**(nf1+ni1-1)
      ss9= gy(i1)*gy(j1)*yf1*yi1*fn(nf1+ni1-1)/(zf1+zi1)**(nf1+ni1+0)
      ss0= gy(i1)*gy(j1)*yf1*yi1*fn(nf1+ni1+0)/(zf1+zi1)**(nf1+ni1+1)
      ss1= gy(i1)*gy(j1)*yf1*yi1*fn(nf1+ni1+1)/(zf1+zi1)**(nf1+ni1+2)
      ss2= gy(i1)*gy(j1)*yf1*yi1*fn(nf1+ni1+2)/(zf1+zi1)**(nf1+ni1+3)
c
      sum8=sum8 +  ss8
      sum9=sum9 +  ss9
      sum0=sum0 +  ss0
      sum1=sum1 +  ss1
      sum2=sum2 +  ss2
c
      vsum=vsum - zt*ss9
      tsum=tsum + 0.5*(li1*(li1+1) - (ni1-1)*ni1) * ss8
      tsum=tsum + zi1*ni1 *ss9 - 0.5*zi1*zi1*ss0
  1   continue
  2   continue
c
      rx8(m)=sum8
      rx9(m)=sum9
      rx0(m)=sum0
      rx1(m)=sum1
      rx2(m)=sum2
      tsm(m)=tsum
      vsm(m)=vsum
  101 continue

c            ------------- FV12, GV12 ------------------
      keyave=0
      do  201  m1=1,mxtabs

      do  202  m2=1,m1
      lmax=      lrnl(m1) + lrnl(m2)
      do 203  lmd=0,lmax
      ccfk=cfk(keyave,m1,lrnl(m1),nexnl(m1),lmd,
     &                m2,lrnl(m2),nexnl(m2))
      if(dabs(ccfk).gt.1.e-5) then
      call vqf(m1, m2, lmd, m1, m2, fsum)
      else
      fsum=0.0
      endif
      fv12(lmd+1,m1,m2)=fsum

      ccgk=cgk(keyave,m1,lrnl(m1),nexnl(m1),lmd,
     &                m2,lrnl(m2),nexnl(m2))
      if(dabs(ccgk).gt.1.e-5) then
      call vqg(m1, m2, lmd, m1, m2, gsum)
      else
      gsum=0.0
      endif
      gv12(lmd+1,m1,m2)=gsum

 203  continue
 202  continue
 201  continue
c---------------- calculate total energy -----------
      ekin=0.0
      ezrm1=0.0
      v12=0.0
      do  301  m1=1,mxtabs
c        --------- V12 term = CFK * fv12  ----------
      do  311  m2=1,m1
      lmax=      lrnl(m1) + lrnl(m2)
      do 303  lmd=0,lmax
      ccfk=cfk(keyave,m1,lrnl(m1),nexnl(m1),lmd,
     &                m2,lrnl(m2),nexnl(m2))
      if(dabs(ccfk).gt.1.e-5) then
      v12=v12 + ccfk*fv12(lmd+1,m1,m2)
      endif
 303  continue
 311  continue


c        --------- V12 term = CGK* gv12  ----------
      do  312  m2=1,m1
      lmax=      lrnl(m1) + lrnl(m2)
      do 304  lmd=0,lmax
      ccgk=cgk(keyave,m1,lrnl(m1),nexnl(m1),lmd,
     &                m2,lrnl(m2),nexnl(m2))
      if(dabs(ccgk).gt.1.e-5) then
      v12=v12 + ccgk*gv12(lmd+1,m1,m2)
      endif
 304  continue
 312  continue

      ekin=ekin + tsm(m1)*nexnl(m1)
      ezrm1=ezrm1 + vsm(m1)*nexnl(m1)
 301  continue

      epot=ezrm1 + v12
      etot=ekin + epot
      ratio=epot/ekin

      do  502  m=1,mxtabs
      ltabm=nlxnl(m) - 10*( nlxnl(m)/10 )
      do  504  n=m,mxtabs
      vmn(m,n)=0.0
      ltabn=nlxnl(n) - 10*( nlxnl(n)/10 )
      if(n.ne.m .and. ltabm.eq.ltabn) then
      call vifmn(m,n,vmn(m,n))
      endif
 504  continue
 502  continue
      return
      end

      subroutine vifmn(m,n,res)
c---------- < wave function table(m) / wave function table(n) > ----
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs

           sum0=0.0
      do 1 j1=1,mxnlx(m)
      nf1=nlt(m,j1)/10
      lf1=nlt(m,j1) - 10*nf1
      zf1=at(m,j1)
      yf1= dsqrt( (2.*zf1)**(2*nf1+1) / fn(2*nf1) )

      do 2 i1=1,mxnlx(n)
      ni1=nlt(n,i1)/10
      li1=nlt(n,i1) - 10*ni1
      zi1=at(n,i1)
      yi1= dsqrt( (2.*zi1)**(2*ni1+1) / fn(2*ni1) )
      sum0=sum0 +  gt(n,i1)*gt(m,j1)*yf1*yi1
     &            *fn(nf1+ni1)/(zf1+zi1)**(nf1+ni1+1)

 2    continue
 1    continue
      res=sum0
      return
      end

      subroutine vqf(ntabi1, ntabi2, lmd, ntabf1, ntabf2,fsum)
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      kmaxi1=mxnlx(ntabi1)
      kmaxi2=mxnlx(ntabi2)
      kmaxf1=mxnlx(ntabf1)
      kmaxf2=mxnlx(ntabf2)
      fsum=0.0

      do 1 j1=1,kmaxf1
      nf1=nlt(ntabf1,j1)/10
      lf1=nlt(ntabf1,j1) - 10*nf1
      zf1= at(ntabf1,j1)
      yf1= dsqrt( (2.*zf1)**(2*nf1+1) / fn(2*nf1) )

          do 2 i1=1,kmaxi1
          ni1=nlt(ntabi1,i1)/10
          li1=nlt(ntabi1,i1) - 10*ni1
          zi1= at(ntabi1,i1)
          yi1= dsqrt( (2.*zi1)**(2*ni1+1) / fn(2*ni1) )
c
      do 3 j2=1,kmaxf2
      nf2=nlt(ntabf2,j2)/10
      lf2=nlt(ntabf2,j2) - 10*nf2
      zf2= at(ntabf2,j2)
      yf2= dsqrt( (2.*zf2)**(2*nf2+1) / fn(2*nf2) )

      do 4 i2=1,kmaxi2
      ni2=nlt(ntabi2,i2)/10
      li2=nlt(ntabi2,i2) - 10*ni2
      zi2= at(ntabi2,i2)
      yi2= dsqrt( (2.*zi2)**(2*ni2+1) / fn(2*ni2) )

           z11=zi1 + zf1
           z22=zi2 + zf2
           j11=ni1 + nf1 - 2
           j22=ni2 + nf2 - 2

      fsum=fsum + gt(ntabi1,i1)*gt(ntabf1,j1)*yf1*yi1*
     &            gt(ntabi2,i2)*gt(ntabf2,j2)*yf2*yi2
     &            *sr(lmd,j11,z11,j22,z22)
  4   continue
  3   continue
  2   continue
  1   continue
      return
      end

      subroutine vqg(ntabi1, ntabi2, lmd, ntabf1, ntabf2,gsum)
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      kmaxi1=mxnlx(ntabi1)
      kmaxi2=mxnlx(ntabi2)
      kmaxf1=mxnlx(ntabf1)
      kmaxf2=mxnlx(ntabf2)
      gsum=0.0

      do 1 j1=1,kmaxf1
      nf1=nlt(ntabf1,j1)/10
      lf1=nlt(ntabf1,j1) - 10*nf1
      zf1= at(ntabf1,j1)
      yf1= dsqrt( (2.*zf1)**(2*nf1+1) / fn(2*nf1) )

          do 2 i1=1,kmaxi1
          ni1=nlt(ntabi1,i1)/10
          li1=nlt(ntabi1,i1) - 10*ni1
          zi1= at(ntabi1,i1)
          yi1= dsqrt( (2.*zi1)**(2*ni1+1) / fn(2*ni1) )
c
      do 3 j2=1,kmaxf2
      nf2=nlt(ntabf2,j2)/10
      lf2=nlt(ntabf2,j2) - 10*nf2
      zf2= at(ntabf2,j2)
      yf2= dsqrt( (2.*zf2)**(2*nf2+1) / fn(2*nf2) )

      do 4 i2=1,kmaxi2
      ni2=nlt(ntabi2,i2)/10
      li2=nlt(ntabi2,i2) - 10*ni2
      zi2= at(ntabi2,i2)
      yi2= dsqrt( (2.*zi2)**(2*ni2+1) / fn(2*ni2) )

           z12=zi1 + zf2
           z21=zi2 + zf1
           j12=ni1 + nf2 - 2
           j21=ni2 + nf1 - 2

      gsum=gsum + gt(ntabi1,i1)*gt(ntabf1,j1)*yf1*yi1*
     &            gt(ntabi2,i2)*gt(ntabf2,j2)*yf2*yi2
     &            *sr(lmd,j12,z12,j21,z21)
  4   continue
  3   continue
  2   continue
  1   continue
      return
      end

           function  sr(ll,n1,z1,n2,z2)
c----------------- calculate integral dr1, dr2  from ----------------
c  r1**(2+n1) *r2**(2+n2) * exp(-z1*r1-z2*r2) * (r<)**ll/(r>)**(ll+1)
c--------------------------------------------------------------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      sum1=0.0
      jmax1=n1+ll+2
      f1=fn(n1+ll+2)
      do 1 jj1=1,jmax1
      j1=jj1-1
      sum1=sum1+f1/fn(n1+ll+2-j1) * 1./(z1**(j1+1))
     &           * fn(n1+n2+3-j1)/((z1+z2)**(n1+n2+4-j1))
   1  continue
c-
      if(ll.ge.n2+2)  then
      sum2=f1/(z1**(n1+ll+3)) * dlog(1.+z1/z2)
      else
      sum2=f1*fn(n2-ll+1)/(z1**(n1+ll+3))
     & *(  1./(z2**(n2-ll+2)) -1./((z1+z2)**(n2-ll+2)) )
      endif
c--
      sum3=0.0
      jmax2=n2+ll+2
      f2=fn(n2+ll+2)
      do 2 jj2=1,jmax2
      j2=jj2-1
      sum3=sum3+f2/fn(n2+ll+2-j2) * 1./(z2**(j2+1))
     &           * fn(n1+n2+3-j2)/((z1+z2)**(n1+n2+4-j2))
   2  continue
      if(ll.ge.n1+2)  then
      sum4=f2/(z2**(n2+ll+3)) * dlog(1.+z2/z1)
      else
      sum4=f2*fn(n1-ll+1)/(z2**(n2+ll+3))
     & *(  1./(z1**(n1-ll+2)) -1./((z1+z2)**(n1-ll+2)) )
      endif
      sr= - sum1 + sum2 - sum3 + sum4
      return
      end


                        function fn(k)
c-----------------------   fn(k)=k! --------------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      if(k.lt.0) write(*,21) k
  21  format(5x,'error in fn(k) function  k=',i5)
      fn=1.0
      if(k.le.1) return
      do 1 i=1,k
   1  fn=fn*dfloat(i)
      return
      end


      function  cfk(keyave,n1,l1,ne1,lmd,n2,l2,ne2)
      implicit real*8(a-h,o-z), integer*4 (i-n)
      cfk=0.0
      if(n1.eq.n2.and.l1.eq.l2.and.ne1.eq.1.and.ne2.eq.1) return
c                  ---------------------
c                       lmd=0
c                  ---------------------
      if(lmd.eq.0) then
      cfk=ne1*ne2
         if(n1.eq.n2 .and. l1.eq.l2 .and.  ne1.eq.ne2)  then
         if(ne1.eq.2 )  cfk= 1.0
         if(ne1.eq.3 )  cfk= 3.0
         if(ne1.eq.4 )  cfk= 6.0
         if(ne1.eq.5 )  cfk=10.0
         if(ne1.eq.6 )  cfk=15.0
         if(ne1.eq.7 )  cfk=21.0
         if(ne1.eq.8 )  cfk=28.0
         if(ne1.eq.9 )  cfk=36.0
         if(ne1.eq.10)  cfk=45.0
         endif
      endif
c                  ---------------------
c                       lmd=2
c                  ---------------------
       if(lmd.eq.2) then

      if(l1.eq.1 .and. l2.eq.1) then
c
       if(ne1.eq.2 .and. ne2.eq.2 .and. n1.ne.n2) cfk=-0.2
       if(ne1.eq.3 .and. ne2.eq.3 .and. n1.ne.n2) cfk=-0.6
       if(ne1.eq.4 .and. ne2.eq.4 .and. n1.ne.n2) cfk=-0.6

      if(keyave.le.0) then
      if(ne1.eq.2 .and. ne2.eq.2 .and. n1.eq.n2) cfk=-0.2
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.eq.n2) cfk=-0.6
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.eq.n2) cfk=-0.6
      else
c--------------------- average term ---------------
      if(ne1.eq.2 .and. ne2.eq.2 .and. n1.eq.n2) cfk=-0.08
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.eq.n2) cfk=-0.24
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.eq.n2) cfk=-0.48
      endif

      if(ne1.eq.5 .and. ne2.eq.5) cfk=-0.8
      if(ne1.eq.6 .and. ne2.eq.6) cfk=-1.2
      endif


      if(l1.eq.2 .and. l2.eq.2) then
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.ne.n2) cfk=-0.09523810
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.ne.n2) cfk=-0.19047619
      if(ne1.eq.5 .and. ne2.eq.5 .and. n1.ne.n2) cfk=-0.31746032
      if(ne1.eq.6 .and. ne2.eq.6 .and. n1.ne.n2) cfk=-0.47619048
      if(ne1.eq.7 .and. ne2.eq.7 .and. n1.ne.n2) cfk=-0.66666667
      if(ne1.eq.8 .and. ne2.eq.8 .and. n1.ne.n2) cfk=-0.88888889
      if(ne1.eq.9 .and. ne2.eq.9)                cfk=-1.14285714
      if(ne1.eq.10.and. ne1.eq.10.and. n1.eq.n2) cfk=-1.42857143

      if(keyave.le.0) then
      if(ne1.eq.2 .and. ne1.eq.2 .and. n1.eq.n2) cfk=-0.16326531
      if(ne1.eq.3 .and. ne1.eq.3 .and. n1.eq.n2) cfk=-0.30612245
      if(ne1.eq.4 .and. ne1.eq.4 .and. n1.eq.n2) cfk=-0.42857143
      if(ne1.eq.5 .and. ne1.eq.5 .and. n1.eq.n2) cfk=-0.71428571
      if(ne1.eq.6 .and. ne1.eq.6 .and. n1.eq.n2) cfk=-0.71428571
      if(ne1.eq.7 .and. ne1.eq.7 .and. n1.eq.n2) cfk=-0.87755102
      if(ne1.eq.8 .and. ne1.eq.8 .and. n1.eq.n2) cfk=-1.02040816
c--------------------- average energy of term ---------------
      else
      if(ne1.eq.2 .and. ne1.eq.2 .and. n1.eq.n2) cfk=-0.03174603
      if(ne1.eq.3 .and. ne1.eq.3 .and. n1.eq.n2) cfk=-0.09523810
      if(ne1.eq.4 .and. ne1.eq.4 .and. n1.eq.n2) cfk=-0.19047619
      if(ne1.eq.5 .and. ne1.eq.5 .and. n1.eq.n2) cfk=-0.31746032
      if(ne1.eq.6 .and. ne1.eq.6 .and. n1.eq.n2) cfk=-0.47619048
      if(ne1.eq.7 .and. ne1.eq.7 .and. n1.eq.n2) cfk=-0.66666667
      if(ne1.eq.8 .and. ne1.eq.8 .and. n1.eq.n2) cfk=-0.88888889
      endif
      endif

      endif
c                  ---------------------
c                       lmd=4
c                  ---------------------
       if(lmd.eq.4) then

      if(l1.eq.2.and.l2.eq.2) then
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.ne.n2) cfk=-0.09523810
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.ne.n2) cfk=-0.19047619
      if(ne1.eq.5 .and. ne2.eq.5 .and. n1.ne.n2) cfk=-0.31746032
      if(ne1.eq.6 .and. ne2.eq.6 .and. n1.ne.n2) cfk=-0.47619048
      if(ne1.eq.7 .and. ne2.eq.7 .and. n1.ne.n2) cfk=-0.66666667
      if(ne1.eq.8 .and. ne2.eq.8 .and. n1.ne.n2) cfk=-0.88888889
      if(ne1.eq.9 .and. ne2.eq.9)                cfk=-1.14285714
      if(ne1.eq.10.and. ne2.eq.10.and. n1.eq.n2) cfk=-1.42857143

      if(keyave.le.0) then
      if(ne1.eq.2 .and. ne2.eq.2 .and. n1.eq.n2) cfk=-0.02040816
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.eq.n2) cfk=-0.16326531
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.eq.n2) cfk=-0.42857143
      if(ne1.eq.5 .and. ne2.eq.5 .and. n1.eq.n2) cfk=-0.71428571
      if(ne1.eq.6 .and. ne2.eq.6 .and. n1.eq.n2) cfk=-0.71428571
      if(ne1.eq.7 .and. ne2.eq.7 .and. n1.eq.n2) cfk=-0.73469388
      if(ne1.eq.8 .and. ne2.eq.8 .and. n1.eq.n2) cfk=-0.87755102
c--------------------- average energy of term ---------------
      else
      if(ne1.eq.2 .and. ne2.eq.2 .and. n1.eq.n2) cfk=-0.03174603
      if(ne1.eq.3 .and. ne2.eq.3 .and. n1.eq.n2) cfk=-0.09523810
      if(ne1.eq.4 .and. ne2.eq.4 .and. n1.eq.n2) cfk=-0.19047619
      if(ne1.eq.5 .and. ne2.eq.5 .and. n1.eq.n2) cfk=-0.31746032
      if(ne1.eq.6 .and. ne2.eq.6 .and. n1.eq.n2) cfk=-0.47619048
      if(ne1.eq.7 .and. ne2.eq.7 .and. n1.eq.n2) cfk=-0.66666667
      if(ne1.eq.8 .and. ne2.eq.8 .and. n1.eq.n2) cfk=-0.88888889
      endif

      endif

      endif

      return
      end

      function  cgk(keyave,n1,l1,ne1,lmd,n2,l2,ne2)
c----------------------------------------------------------------------
c   keyave=0/1    calculations for this term/ average energy of term
c----------------------------------------------------------------------
      implicit real*8(a-h,o-z), integer*4 (i-n)
      cgk=0.0
c                  ---------------------
c                       lmd=0
c                  ---------------------
      if(lmd.eq.0 .and. n1.ne.n2)    then
      if(l1.eq.0.and.l2.eq.0)  cgk=-ne1*ne2/2.0
      if(l1.eq.1.and.l2.eq.1)  cgk=-ne1*ne2/6.0
      if(l1.eq.2.and.l2.eq.2)  cgk=-ne1*ne2/10.0
      endif
c                  ---------------------
c                       lmd=1
c                  ---------------------
      if(lmd.eq.1) then
      if(l1.eq.1.and.l2.eq.0) cgk=-ne2*ne1/6.0
      if(l2.eq.1.and.l1.eq.0) cgk=-ne2*ne1/6.0
      if(l1.eq.1.and.l2.eq.2) cgk=-2.0*ne1*ne2/30.0
      if(l2.eq.1.and.l1.eq.2) cgk=-2.0*ne1*ne2/30.0
      endif
c                  ---------------------
c                       lmd=2
c                  ---------------------
      if(lmd.eq.2) then
      if(l1.eq.0 .and. ne1.eq.2 .and. l2.eq.2) cgk=-0.2*ne2
      if(l2.eq.0 .and. ne2.eq.2 .and. l1.eq.2) cgk=-0.2*ne1
c


      if(keyave.le.0) then
      if(l1.eq.0 .and. ne1.eq.1 .and. l2.eq.2) cgk=-1.0
      if(l2.eq.0 .and. ne2.eq.1 .and. l1.eq.2) cgk=-1.0
c--------------------- average energy of term ---------------
      else
      if(l1.eq.0 .and. ne1.eq.1 .and. l2.eq.2) cgk=-ne2/10.0
      if(l2.eq.0 .and. ne2.eq.1 .and. l1.eq.2) cgk=-ne1/10.0
      endif

c
      if(n1.ne.n2) then
      if(l1.eq.1.and.l2.eq.1) cgk=-2.0*ne1*ne2/30.0
      if(l1.eq.2.and.l2.eq.2) cgk=-2.0*ne1*ne2/70.0
      endif

      endif
c                  ---------------------
c                       lmd=3
c                  ---------------------
      if(lmd.eq.3) then
      if(l1.eq.1.and.l2.eq.2)  cgk=-3.0*ne1*ne2/70.0
      if(l2.eq.1.and.l1.eq.2)  cgk=-3.0*ne1*ne2/70.0
      endif
c                  ---------------------
c                       lmd=4
c                  ---------------------
      if(lmd.eq.4) then
      if(l1.eq.2.and.l1.eq.2)  cgk=-2.0*ne1*ne2/70.0
      endif
      return
      end

      subroutine wfout
c----------------- write results to 'wf_rhf.out' ----------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      character  h1(5)*1
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      common/engrhf/ rx8(jtabs),rx9(jtabs),rx0(jtabs),rx1(jtabs),
     &     rx2(jtabs),tsm(jtabs),vsm(jtabs),vmn(jtabs,jtabs),
     &     fv12(jlmd,jtabs,jtabs),gv12(jlmd,jtabs,jtabs),
     &     eorbit(jtabs),etot,ekin,epot,ratio,v12
      dimension    mlab(jtabs)
      data  h1/ 's', 'p', 'd', 'f', 'g' /
c---------------------  print  summary --------------------
      write(15,60)   ne,nzt,nsptot,lrtot,mxtabs,key
  60  format(5x,'Ne=',i2,'  Z=',i2,'   Nspin=',i2,'  Ltot=',i2,
     &       '  mxtabs=',i2,'   key=',i2,/,/)
      if(key.eq.1) write(15,31)
      if(key.eq.2) write(15,32)
      if(key.eq.3) write(15,33)
  31  format(/,'ROOTHAAN-HARTREE-FOCK WAVE FUNCTIONS',/,
     & '  Clementi E., Roetti C. // Atomic data and',
     &  ' Nuclear data Tables v.14, 177-478 (1974)',/)
  32  format(/,'ROOTHAAN-HARTREE-FOCK WAVE FUNCTIONS',/,
     & ' Bunge C.F. et all, //',
     & 'Atomic Data and Nuclear Data Tables 53,113-162(1993)',/,
     & ' Bunge C.F. at all //Phys. Rev. A46,3691-3696(1992)',/,1x,
     & 'www.ccl.net/cca/data/atomic-RHF-wavefunctions/index.shtml',/)
  33  format(/,'RELATIVISTIC WAVE FUNCTIONS',/,
     &  'Su Z., Coppens P., // Acta Cryst. A53, 749-762 (1997);',/,
     &  'Macchi P., Coppens P., // Acta Cryst.A57, 656-662 (2001)',/,
     &  '  http://harker.chem.buffalo.edu/group/wavtable.html',/)


      do  51  ll=0,2
      kk=0
      do  52  m=1,mxtabs
      if(ll.eq. nlxnl(m) - 10*( nlxnl(m)/10 ) ) then
      kk=kk+1
      mlab(kk)=m
      endif
  52  continue
      kmax=kk
      if(kmax.eq.0)  goto 51

      mxnlts=mxnlx(mlab(1))

      do 53 k=1,kmax
      if(mxnlts .ne. mxnlx(mlab(k)) ) then
      write(15,58)   mxnlts,nlxnl(mlab(k))
  58  format('   error:  mxnlts=',i2,' not equal  mxnlx(',i2,')')
      goto 53
      endif
  53  continue

      write(15,71)  (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)
   71 format(/,/,28x,5(i1,a1,12x))


      do 54 j=1,mxnlts
      write(15,79) nlt(mlab(1),j)/10,h1(ll+1),at(mlab(1),j),
     &                (gt(mlab(k),j),k=1,kmax)
  79  format(2x,i2,a1,1x,f12.6,3x,5(f12.8,2x))
  54  continue

      if(key.ne.3)  write(15,72)  (enl(mlab(k)),k=1,kmax)
      write(15,70)
      write(15,73)  (rx0(mlab(k)),k=1,kmax)
      write(15,74)  (rx1(mlab(k)),k=1,kmax)
      write(15,75)  (rx2(mlab(k)),k=1,kmax)
      write(15,76)  (rx9(mlab(k)),k=1,kmax)
      write(15,77)  (rx8(mlab(k)),k=1,kmax)
      write(15,70)
   70 format(1x)
   72 format(/,'ORB.ENERGY,a.u.',6x,5(f12.6,2x) )
   73 format(' NORM     ',11x,5(f12.6,2x) )
   74 format(' <R>      ',11x,5(f12.6,2x) )
   75 format(' <R2>     ',11x,5(f12.6,2x) )
   76 format(' <1/R>    ',11x,5(f12.6,2x) )
   77 format('<1/R**2>  ',11x,5(f12.6,2x) )
  51  continue
c--------------------- testing ---------------------
      if(key.ne.3) write(15,61)    etot,ekin,epot,ratio
  61  format(/,
     &       10x,'  Total   Energy=',f16.8,' a.u.',/,
     &       10x,' Kinetic  Energy=',f16.8,' a.u.',/,
     &       10x,'Potential Energy=',f16.8,' a.u.',/,
     &       10x,'  Virial Ratio  =',f16.8,/)

      write(15,21)
  21  format(/,/,23x,'***** TESTING: *****')

      do  1  m=1,mxtabs
      ltabm=nlxnl(m) - 10*( nlxnl(m)/10 )
      write(15,26)  nlxnl(m)/10,h1(ltabm+1),
     &              nlxnl(m)/10,h1(ltabm+1),1.0-rx0(m)
  26  format(20x,'1.0 - <',i1,a1,1x,i1,a1,'>   =',e12.4)
 1    continue
      write(15,70)

      do  2  m=1,mxtabs
      do  3  n=1,m
      ltabm=nlxnl(m) - 10*( nlxnl(m)/10 )
      ltabn=nlxnl(n) - 10*( nlxnl(n)/10 )
      if(n.ne.m  .and. ltabm.eq.ltabn)  then
      write(15,25) nlxnl(n)/10, h1(ltabn+1),
     &             nlxnl(m)/10, h1(ltabm+1),vmn(n,m)
  25  format(20x,'<',i1,a1,2x,i1,a1,'>        =',e12.4)
      endif
 3    continue
 2    continue
      return
      end

         subroutine  wfhtm
c----------------- write results to 'wf_rhf.htm' ----------------
      implicit real*8 (a-h,o-z), integer*4 (i-n)
      parameter   ( jcmain=50, jtabs=20, jlmd=7)
      character   h1(5)*1,hm1*1,hm2*1, hlres*1, hname(54)*2
      character hsig*1
      common/rhf/  gt(jtabs,jcmain),at(jtabs,jcmain),enl(jtabs),
     &   nlt(jtabs,jcmain),mxnlx(jtabs), nexnl(jtabs),nlxnl(jtabs),
     &   ne,nzt,key,nsptot,lrtot,mxtabs
      common/engrhf/ rx8(jtabs),rx9(jtabs),rx0(jtabs),rx1(jtabs),
     &     rx2(jtabs),tsm(jtabs),vsm(jtabs),vmn(jtabs,jtabs),
     &     fv12(jlmd,jtabs,jtabs),gv12(jlmd,jtabs,jtabs),
     &     eorbit(jtabs),etot,ekin,epot,ratio,v12
      dimension    mlab(jtabs)
      dimension   nlx1(54),nex1(54),nlx2(54),nex2(54)
      data nlx1/ 10, 10, 20, 20, 21, 21, 21, 21, 21, 21,
     &           30, 30, 31, 31, 31, 31, 31, 31, 40, 40,
     &           32, 32, 32, 32, 32, 32, 32, 32, 32, 32,
     &           41, 41, 41, 41, 41, 41, 50, 50, 42, 42,
     &           42, 42, 42, 42, 42, 42, 42, 42, 51, 51,
     &           51, 51, 51, 51/
      data nex1/  1,  2,  1,  2,  1,  2,  3,  4,  5,  6,
     &            1,  2,  1,  2,  3,  4,  5,  6,  1,  2,
     &            1,  2,  3,  5,  5,  6,  7,  8, 10, 10,
     &            1,  2,  3,  4,  5,  6,  1,  2,  1,  2,
     &            4,  5,  5,  7,  8, 10, 10, 10,  1,  2,
     &            3,  4,  5,  6 /
      data nlx2/  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &            0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &           40, 40, 40, 40, 40, 40, 40, 40, 40, 40,
     &            0,  0,  0,  0,  0,  0,  0,  0, 50, 50,
     &           50, 50, 50, 50, 50,  0, 50, 50,  0,  0,
     &            0,  0,  0,  0/
      data nex2/  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &            0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     &            2,  2,  2,  1,  2,  2,  2,  2,  1,  2,
     &            0,  0,  0,  0,  0,  0,  0,  0,  2,  2,
     &            1,  1,  2,  1,  1,  0,  1,  2,  0,  0,
     &            0,  0,  0,  0/
      data  h1/ 's', 'p', 'd', 'f', 'g' /
      data  hname/' H','He','Li','Be',' B',' C',' N',' O',' F','Ne',
     &    'Na','Mg','Al','Si',' P',' S','Cl','Ar',' K','Ca',
     &    'Sc','Ti',' V','Cr','Mn','Fe','Co','Ni','Cu','Zn',
     &    'Ga','Ge','As','Se','Br','Kr','Rb','Sr',' Y','Zr',
     &    'Nb','Mo','Tc','Ru','Rh','Pd','Ag','Cd','In','Sn',
     &    'Sb','Te',' I','Xe'  /

      open(18,file='wf_rhf.htm',status='unknown')
      n1=nlx1(ne)/10
      l1=nlx1(ne) - 10*n1
      n2=nlx2(ne)/10
      l2=nlx2(ne) - 10*n2

      hsig='+'
      hlres=' '
      if(lrtot.eq.0) hlres='S'
      if(lrtot.eq.1) hlres='P'
      if(lrtot.eq.2) hlres='D'
      if(lrtot.eq.3) hlres='F'
      if(lrtot.eq.4) hlres='G'
      if(lrtot.eq.5) hlres='H'


      hm1=' '
      if(l1.eq.0) hm1='s'
      if(l1.eq.1) hm1='p'
      if(l1.eq.2) hm1='d'
      if(l1.eq.3) hm1='f'
      if(l1.eq.4) hm1='g'
      if(l1.eq.5) hm1='h'
      hm2=' '
      if(l2.eq.0) hm2='s'
      if(l2.eq.1) hm2='p'
      if(l2.eq.2) hm2='d'
      if(l2.eq.3) hm2='f'
      if(l2.eq.4) hm2='g'
      if(l2.eq.5) hm2='h'
      write(18,20)
      if(ne.le.18)  write(18,21)
      if(ne.ge.19)  write(18,22)
  20  format(
     &   '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0',
     &     ' Transitional//EN">',
     & /,'<HTML><HEAD><TITLE> Wave function',
     &   '  </TITLE>',
     & /,'<META http-equiv=Content-Type content="text/html;',
     &   ' charset=windows-1251">',
     & /,'<META content="MSHTML 6.00.2800.1170"',
     &    ' name=GENERATOR></HEAD>',
     & /,' <BODY bgColor=#fff8dc>',/,/,/)
  21  format( '<p align="center" > <A href="../hf02-18.htm','">
     &         <h3> RETURN  </h3> </a> </p>',/)
  22  format( '<p align="center" > <A href="../hf19-54.htm','">
     &         <h3> RETURN  </h3> </a> </p>',/)

      if(nex2(ne).eq.0)  write(18,41)  n1,hm1,nex1(ne),nsptot,hlres
      if(nex2(ne).ge.1)  write(18,42)  n1,hm1,nex1(ne),
     &                                 n2,hm2,nex2(ne),nsptot,hlres
  41  format(
     &     /, ' <p> <font size="7" color="green"><strong>',
     &    '(',i1,a1,' <sup> ',i2,'  </sup> )',
     &    ' <sup> ',i1,'  </sup> ',a1,' &nbsp; &nbsp; &nbsp;')
  42  format(
     &     /, ' <p> <font size="7" color="green"><strong>',
     &     '(',i1,a1,' <sup> ',i2,'  </sup> ',
     &           i1,a1,' <sup> ',i2,'  </sup>) ',
     &    ' <sup> ',i1,'  </sup> ',a1,' &nbsp; &nbsp; &nbsp;')

      if(nzt-ne.lt.0) hsig='-'
      if(nzt-ne.eq.0) hsig=' '
      if(nzt-ne.gt.0) hsig='+'

      if(nzt.eq.ne .or.  nzt.gt.ne+1) then
      write(18,23)  nzt,hname(nzt),iabs(nzt-ne),hsig,key
      else
      write(18,24)  nzt,hname(nzt),hsig,key
      endif
  23  format('Z=',i2,' &nbsp;  &nbsp; &nbsp; ',a2,
     &        ' <sup> ',i2,a1,' </sup>',
     &  '</strong></font></p>',/,'<font size="5">',
     & /,'<p> F( <b> r </b> )  =  &Sigma; <sub> j </sub>',
     & '  &nbsp;  C <sub> j </sub>  &nbsp;',
     & /,'S <sub> nl </sub> ( &alpha; <sub> j </sub>,r)   Y<sub>'
     & ,'  l,m</sub> ( <b> r </b>  )  </p>',/
     &    '<p align="left"> <b> Table',i2,'. </b> </p>')
  24  format('Z=',i2,' &nbsp;  &nbsp; &nbsp; ',a2,
     &        ' <sup> ',a1,' </sup>',
     &  '</strong></font></p>',/,'<font size="5">',
     & /,'<p> F( <b> r </b> )  =  &Sigma; <sub> j </sub>',
     & '  &nbsp;  C <sub> j </sub>  &nbsp;',
     & /,'S <sub> nl </sub> ( &alpha; <sub> j </sub>,r)   Y<sub>'
     & ,'  l,m</sub> ( <b> r </b>  )  </p>',/
     &    '<p align="left"> <b> Table',i2,'. </b> </p>')

      if(key.eq.1) write(18,31)
      if(key.eq.2) write(18,32)
      if(key.eq.3) write(18,33)
 31   format(/,
     & '<p align="left">',
     &          ' ROOTHAAN-HARTREE-FOCK WAVE FUNCTIONS: </p>',/,
     & '<p align="left">',
     &  '  Clementi E., Roetti C. // Atomic',
     &  ' data and Nuclear data Tables v.14, 177-478 (1974) </p>')
c
 32   format(/,
     & '<p align="left">',
     &          ' ROOTHAAN-HARTREE-FOCK WAVE FUNCTIONS: </p>',/,
     & '<p align="left"> Bunge C.F. et all, //',
     & ' Atomic Data and Nuclear Data Tables 53,113-162(1993) </p>',
     &   /,'<p align="left"> Bunge C.F. at all //Phys. Rev. A46,',
     &     ' 3691-3696(1992) </p>',/,
     & '<p align="left" >  <A href="http://',
     & 'www.ccl.net/cca/data/atomic-RHF-wavefunctions/index.shtml">',
     & 'www.ccl.net/cca/data/atomic-RHF-wavefunctions/index.shtml',
     &   '  </a>  </p>')

  33  format(/,
     & '<p align="left">',
     &             ' RELATIVISTIC WAVE FUNCTIONS: </p>',/,
     & '<p align="left">',
     &  'Su Z., Coppens P.// Acta Cryst. A53, 749-762 (1997);</p>',/,
     &  'Macchi P., Coppens P., // Acta Cryst.A57, 656-662 (2001)',
     &   ' </p>',/,
     & '<p align="left" >  <A href="http://',
     & 'harker.chem.buffalo.edu/group/wavtable.html">',
     & 'harker.chem.buffalo.edu/group/wavtable.html',
     &   '  </a>  </p>')


      do  51  ll=0,2
      kk=0
      do  52  m=1,mxtabs
      if(ll.eq. nlxnl(m) - 10*( nlxnl(m)/10 ) ) then
      kk=kk+1
      mlab(kk)=m
      endif
  52  continue
      kmax=kk
      if(kmax.eq.0)  goto 51
      mxnlts=mxnlx(mlab(1))
c---------------------------- start of table ----------------------
      if(kmax.eq.1) write(18,131)
      if(kmax.eq.2) write(18,132)
      if(kmax.eq.3) write(18,133)
      if(kmax.eq.4) write(18,134)
      if(kmax.eq.5) write(18,135)
 131  format( /,'<TABLE width=280 border=2 >',
     & /,'<TR>',
     & /,'<TD align=center width=40  rowspan=2>       j  </TD>',
     & /,'<TD align=center width=140 colspan=2 >  S <sub> nl <sub> j',
     &       ' </sub> </sub>(&alpha;<sub> j </sub>,r)  </TD>',
     & /,'<TD align=center width=100 >',
     &    '   C<sub> j </sub> </TD>',
     & /,'</TR><TR>',
     & /,'<TD align=center width=60>  nl <sub> j </sub> </TD>',
     & /,'<TD align=center width=80>  &alpha;<sub> j</sub> </TD>')
 132  format( /,'<TABLE width=380 border=2 >',
     & /,'<TR>',
     & /,'<TD align=center width=40  rowspan=2>       j  </TD>',
     & /,'<TD align=center width=140 colspan=2 >  S <sub> nl <sub> j',
     &       ' </sub> </sub>(&alpha;<sub> j </sub>,r)  </TD>',
     & /,'<TD align=center width=200 colspan=2>',
     &    '   C<sub> j </sub> </TD>',
     & /,'</TR><TR>',
     & /,'<TD align=center width=60>  nl <sub> j </sub> </TD>',
     & /,'<TD align=center width=80>  &alpha;<sub> j</sub> </TD>')
 133  format( /,'<TABLE width=480 border=2 >',
     & /,'<TR>',
     & /,'<TD align=center width=40  rowspan=2>       j  </TD>',
     & /,'<TD align=center width=140 colspan=2 >  S <sub> nl <sub> j',
     &       ' </sub> </sub>(&alpha;<sub> j </sub>,r)  </TD>',
     & /,'<TD align=center width=300 colspan=3>',
     &    '   C<sub> j </sub> </TD>',
     & /,'</TR><TR>',
     & /,'<TD align=center width=60>  nl <sub> j </sub> </TD>',
     & /,'<TD align=center width=80>  &alpha;<sub> j</sub> </TD>')
 134  format( /,'<TABLE width=580 border=2 >',
     & /,'<TR>',
     & /,'<TD align=center width=40  rowspan=2>       j  </TD>',
     & /,'<TD align=center width=140 colspan=2 >  S <sub> nl <sub> j',
     &       ' </sub> </sub>(&alpha;<sub> j </sub>,r)  </TD>',
     & /,'<TD align=center width=400 colspan=4>',
     &    '   C<sub> j </sub> </TD>',
     & /,'</TR><TR>',
     & /,'<TD align=center width=60>  nl <sub> j </sub> </TD>',
     & /,'<TD align=center width=80>  &alpha;<sub> j</sub> </TD>')
 135  format( /,'<TABLE width=680 border=2 >',
     & /,'<TR>',
     & /,'<TD align=center width=40  rowspan=2>       j  </TD>',
     & /,'<TD align=center width=140 colspan=2 >  S <sub> nl <sub> j',
     &       ' </sub> </sub>(&alpha;<sub> j </sub>,r)  </TD>',
     & /,'<TD align=center width=500 colspan=5>',
     &    '   C<sub> j </sub> </TD>',
     & /,'</TR><TR>',
     & /,'<TD align=center width=60>  nl <sub> j </sub> </TD>',
     & /,'<TD align=center width=80>  &alpha;<sub> j</sub> </TD>')
c---------------------------- title of table ----------------------
      if(kmax.eq.1)write(18,141)
     &         (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)
      if(kmax.eq.2)write(18,142)
     &         (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)
      if(kmax.eq.3)write(18,143)
     &         (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)
      if(kmax.eq.4)write(18,144)
     &         (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)
      if(kmax.eq.5)write(18,145)
     &         (nlxnl(mlab(k))/10,h1(ll+1),k=1,kmax)

 141  format(
     & /,'<TD align=center width=100>  ',i1,a1,'- electron </TD>',
     & /,/,'</TR><TR>')
 142  format(
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,/,'</TR><TR>')
 143  format(
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,/,'</TR><TR>')
 144  format(
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,/,'</TR><TR>')
 145  format(
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,'<TD align=center width=100> ',i1,a1,' - electron </TD>',
     & /,/,'</TR><TR>')
c---------------------------- data of table ----------------------
      do 54 j=1,mxnlts
      if(kmax.eq.1) write(18,151) j,nlt(mlab(1),j)/10,h1(ll+1),
     &           at(mlab(1),j),(gt(mlab(k),j),k=1,kmax)
      if(kmax.eq.2) write(18,152) j,nlt(mlab(1),j)/10,h1(ll+1),
     &           at(mlab(1),j),(gt(mlab(k),j),k=1,kmax)
      if(kmax.eq.3) write(18,153) j,nlt(mlab(1),j)/10,h1(ll+1),
     &           at(mlab(1),j),(gt(mlab(k),j),k=1,kmax)
      if(kmax.eq.4) write(18,154) j,nlt(mlab(1),j)/10,h1(ll+1),
     &           at(mlab(1),j),(gt(mlab(k),j),k=1,kmax)
      if(kmax.eq.5) write(18,155) j,nlt(mlab(1),j)/10,h1(ll+1),
     &           at(mlab(1),j),(gt(mlab(k),j),k=1,kmax)
      write(18,37)
  37  format(/,/,'</TR><TR>',/)
  54  continue
c
 151  format(
     & /,'<TD align=center width=40>   ',i2,'    </TD>',
     & /,'<TD align=center width=60>   ',i1,a1,' </TD>',
     & /,'<TD align=center width=80>   ',f12.6,' </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>')
 152  format(
     & /,'<TD align=center width=40>   ',i2,'    </TD>',
     & /,'<TD align=center width=60>   ',i1,a1,' </TD>',
     & /,'<TD align=center width=80>   ',f12.6,' </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>')
 153  format(
     & /,'<TD align=center width=40>   ',i2,'    </TD>',
     & /,'<TD align=center width=60>   ',i1,a1,' </TD>',
     & /,'<TD align=center width=80>   ',f12.6,' </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>')
 154  format(
     & /,'<TD align=center width=40>   ',i2,'    </TD>',
     & /,'<TD align=center width=60>   ',i1,a1,' </TD>',
     & /,'<TD align=center width=80>   ',f12.6,' </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>')
 155  format(
     & /,'<TD align=center width=40>   ',i2,'    </TD>',
     & /,'<TD align=center width=60>   ',i1,a1,' </TD>',
     & /,'<TD align=center width=80>   ',f12.6,' </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>',
     & /,'<TD align=center width=100>  ',f12.6,'  </TD>')
c---------------------------- end of table ----------------------
      write(18,38)
  38  format(/,'</TR></TABLE>',/,/)

      if(key.ne.3) then
      if(kmax.eq.1) write(18,161)  (enl(mlab(k)),k=1,kmax)
      if(kmax.eq.2) write(18,162)  (enl(mlab(k)),k=1,kmax)
      if(kmax.eq.3) write(18,163)  (enl(mlab(k)),k=1,kmax)
      if(kmax.eq.4) write(18,164)  (enl(mlab(k)),k=1,kmax)
      if(kmax.eq.5) write(18,165)  (enl(mlab(k)),k=1,kmax)
      endif

      if(kmax.eq.1) write(18,171)
     &  (rx0(mlab(k)),k=1,kmax),
     &  (rx1(mlab(k)),k=1,kmax),
     &  (rx2(mlab(k)),k=1,kmax),
     &  (rx9(mlab(k)),k=1,kmax),
     &  (rx8(mlab(k)),k=1,kmax)
      if(kmax.eq.2) write(18,172)
     &  (rx0(mlab(k)),k=1,kmax),
     &  (rx1(mlab(k)),k=1,kmax),
     &  (rx2(mlab(k)),k=1,kmax),
     &  (rx9(mlab(k)),k=1,kmax),
     &  (rx8(mlab(k)),k=1,kmax)
      if(kmax.eq.3) write(18,173)
     &  (rx0(mlab(k)),k=1,kmax),
     &  (rx1(mlab(k)),k=1,kmax),
     &  (rx2(mlab(k)),k=1,kmax),
     &  (rx9(mlab(k)),k=1,kmax),
     &  (rx8(mlab(k)),k=1,kmax)
      if(kmax.eq.4) write(18,174)
     &  (rx0(mlab(k)),k=1,kmax),
     &  (rx1(mlab(k)),k=1,kmax),
     &  (rx2(mlab(k)),k=1,kmax),
     &  (rx9(mlab(k)),k=1,kmax),
     &  (rx8(mlab(k)),k=1,kmax)
      if(kmax.eq.5) write(18,175)
     &  (rx0(mlab(k)),k=1,kmax),
     &  (rx1(mlab(k)),k=1,kmax),
     &  (rx2(mlab(k)),k=1,kmax),
     &  (rx9(mlab(k)),k=1,kmax),
     &  (rx8(mlab(k)),k=1,kmax)
c
 161  format( /,'<TABLE width=280 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  ORB.ENERGY,a.u.  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     &  1x )
 162  format( /,'<TABLE width=380 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  ORB.ENERGY,a.u.  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     &  1x )
 163  format( /,'<TABLE width=480 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  ORB.ENERGY,a.u.  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     &  1x )
 164  format( /,'<TABLE width=580 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  ORB.ENERGY,a.u.  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     &  1x )
 165  format( /,'<TABLE width=680 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  ORB.ENERGY,a.u.  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     &  1x )

 171  format( /,'<TABLE width=280 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  NORM           </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R &gt;    </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R2 &gt;   </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R &gt;  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R**2 &gt; </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     &  1x )
 172  format( /,'<TABLE width=380 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  NORM           </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R &gt;    </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R2 &gt;   </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R &gt;  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R**2 &gt; </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     &  1x )
 173  format( /,'<TABLE width=480 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  NORM           </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R &gt;    </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R2 &gt;   </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R &gt;  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R**2 &gt; </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     &  1x )
 174  format( /,'<TABLE width=580 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  NORM           </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R &gt;    </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R2 &gt;   </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R &gt;  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R**2 &gt; </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     &  1x )
 175  format( /,'<TABLE width=680 border=2 >',/,'<TR>',
     & /,'<TD align=center width=180>  NORM           </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R &gt;    </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; R2 &gt;   </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R &gt;  </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'</TR>',
     & /,'<TD align=center width=180>  &lt; 1/R**2 &gt; </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     & /,'<TD align=center width=100> ',3x,f12.6,3x,' </TD>',
     &  1x )
      write(18,38)
  51  continue
c--------------------- testing ---------------------
      if(key.ne.3) write(18,61)    etot,ekin,epot,ratio
  61  format(
     & '<p align="left">  Total    Energy= ',3x,f16.8,3x,
     &       'a.u.  </p>'/,
     & '<p align="left">  Kinetic  Energy= ',3x,f16.8,3x,
     &       'a.u.  </p>'/,
     & '<p align="left"> Potential Energy= ',3x,f16.8,3x,
     &       'a.u.  </p>'/,
     & '<p align="left">   Virial Ratio  = ',3x,f16.8,3x,
     &       ' </p>'/)

      write(18,101)
 101  format('<p align="left"> <h3> ***** TESTING ***** </h3> </p>')

      do  102  m=1,mxtabs
      ltabm=nlxnl(m) - 10*( nlxnl(m)/10 )
      write(18,103)  nlxnl(m)/10,h1(ltabm+1),
     &              nlxnl(m)/10,h1(ltabm+1),1.0-rx0(m)
 103  format('<p align="left"> <h4>',' 1.0 - <',i1,a1,1x,i1,a1,
     &   '>   =', e12.4,' </h4> </p>')
 102  continue

      do  104  m=1,mxtabs
      do  105  n=1,m
      ltabm=nlxnl(m) - 10*( nlxnl(m)/10 )
      ltabn=nlxnl(n) - 10*( nlxnl(n)/10 )
      if(n.ne.m  .and. ltabm.eq.ltabn) write(18,106) nlxnl(n)/10,
     &   h1(ltabn+1),nlxnl(m)/10, h1(ltabm+1),vmn(n,m)
 106  format('<p align="left"> <h4>',' <',i1,a1,1x,i1,a1,'>   =',
     &   e12.4,' </h4> </p>')
 105  continue
 104  continue


      if(ne.le.18)  write(18,39)
      if(ne.ge.19)  write(18,40)
  39  format(/,'<p align="center" > <A href="../hf02-18.htm"> ',
     &   ' <h3> RETURN </h3> </a> </p>',/,' </font>',
     & /,'</BODY></HTML>',/)
  40  format(/,'<p align="center" > <A href="../hf19-54.htm"> ',
     &   ' <h3> RETURN </h3> </a> </p>',/,' </font>',
     & /,'</BODY></HTML>',/)

      return
      end

